<?php
namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

use Ems\portalGestor\Service\ProcessoService;

class ProcessoController {

    /** @var ProcessoService */
    protected $processoService;

    public function __construct(
        ProcessoService $processoService
    ) {
        $this->processoService = $processoService;
    }

    public function getStatusProcesso(
        Request\Filter  $request,
        Response        $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int)  $row['NRORG'];

            $status = $this->processoService->getStatusProcesso(
                $nrOrg
            );

            $response->addDataSet(new DataSet('data', $status));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getProcessosGestor(
        Request\Filter  $request,
        Response        $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int)  $row['NRORG'];
            $nrParcNegocio = (int)  $row['NRPARCNEGOCIO'];

            $processos = $this->processoService->getProcessosGestor(
                $nrOrg, $nrParcNegocio
            );

            $response->addDataSet(new DataSet('data', $processos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getFasesTemplate(
        Request\Filter  $request,
        Response        $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int)  $row['NRORG'];
            $nrTemplate = (int)  $row['NRTEMPLATE'];

            $fases = $this->processoService->getFasesTemplate(
                $nrOrg, $nrTemplate
            );

            $response->addDataSet(new DataSet('data', $fases));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function getCandidatosFase(
        Request\Filter  $request,
        Response        $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int)  $row['NRORG'];
            $nrProcesso = (int) $row['NRPROCESSO'];
            $nrFase = (int) $row['NRFASE'];

            $candidatos = $this->processoService->getCandidatosFase(
                $nrOrg, $nrProcesso, $nrFase
            );

            $response->addDataSet(new DataSet('data', $candidatos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }

    public function generateResume(
        Request\Filter  $request,
        Response        $response
    ) {
        try {
            $row = $request->getParameters();

            $link = $this->processoService->generateResume(
                $row
            );

            $dataset = [
                'link' => $link,
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
}