<?php
namespace EMS\portalGestor\Service;

use Doctrine\ORM\EntityManager;
use Ems\portalGestor\Repository\OperadorRepository;
use Ems\portalGestor\Util\HcmServices;
use Ems\portalGestor\Util\ExpectedException;

use EMS\portalGestor\Util\DateUtil;

class ProcessoService {

    /** @var HcmServices */
    protected $hcmServices;

    /** @var OperadorRepository */
    protected $operadorRepository;

    public function __construct(
        HcmServices     $hcmServices,
        OperadorRepository $operadorRepository
    ) {
        $this->hcmServices = $hcmServices;
        $this->operadorRepository = $operadorRepository;
    }

    public function getStatusProcesso(
        int $nrOrg
    ): array {
        $route = 'getStatusProcesso';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $motivos = $result['dataset'][$route];

        return $motivos;
    }

    public function getProcessosGestor(
        int $nrOrg,
        int $nrParcNegocio
    ): array {
        $route = 'getProcessosGestor';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRPARCNEGOCIO' => $nrParcNegocio,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $processos = $result['dataset'][$route];

        return $processos;
    }

    public function getFasesTemplate(
        int $nrOrg,
        int $nrTemplate
    ): array {
        $route = 'getFasesTemplate';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRTEMPLATE' => $nrTemplate,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $fases = $result['dataset'][$route];

        return $fases;
    }

    public function getCandidatosFase(
        int $nrOrg,
        int $nrProcesso,
        int $nrFase
    ): array {
        $route = 'getCandidatosFase';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRPROCESSO' => $nrProcesso,
                'NRFASE' => $nrFase,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $candidatos = $result['dataset'][$route];

        return $candidatos;
    }

    public function generateResume(
        array $row
    ): string {
        $nrOrg = 0;
        $nrParcNegocio = (int) $row['NRPARCNEGOCIO'];

        $operador = $this->operadorRepository->getOperadorByNrParcNegocio(
            $nrOrg,
            $nrParcNegocio
        );

        if (!$operador) {
            throw new ExpectedException('Não foi possível encontrar o operador do candidato!');
        }

        $nmOperador = $operador['NMOPERADOR'];

        $pathFoto = '';

        $competencia = date('01/m/Y');
        $reportName = 'curriculo_candidato';

        $route = 'generateBirtReport';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'reportName' => $reportName,
                'P_NRORG' => $nrOrg,
                'P_NRPARCNEGOCIO' => $nrParcNegocio,
                'P_NMOPERADOR' => $nmOperador,
                'P_COMPETENCIA' => $competencia,
                'P_PATH_FOTO' => $pathFoto,
            ],
        ];

        $response = $this->hcmServices->send($route, $params, $nrOrg);
        $reportLink = (string) $response['dataset'][$route]['link'];

        return $reportLink;
    }
}
